==> qtjambi-dbus-debuginfo-macos-6.5.4.jar: sources/QtJambiDBus/QDBusAbstractInterfaceBase_shell.h <==
#ifndef QDBUSABSTRACTINTERFACEBASE_SHELL_H
#define QDBUSABSTRACTINTERFACEBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbusabstractinterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QDBusAbstractInterfaceBase_shell : public QDBusAbstractInterfaceBase, public QtJambiShellInterface
{
public:
    ~QDBusAbstractInterfaceBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusAbstractInterfaceBase_access : public QDBusAbstractInterfaceBase
{
};

#endif // QDBUSABSTRACTINTERFACEBASE_SHELL_H

==> qtjambi-dbus-debuginfo-macos-6.5.7.jar: sources/QtJambiDBus/QDBusAbstractInterfaceBase_shell.h <==
#ifndef QDBUSABSTRACTINTERFACEBASE_SHELL_H
#define QDBUSABSTRACTINTERFACEBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbusabstractinterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QDBusAbstractInterfaceBase_shell : public QDBusAbstractInterfaceBase, public QtJambiShellInterface
{
public:
    ~QDBusAbstractInterfaceBase_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QDBusAbstractInterfaceBase_mshell;
    friend class QDBusAbstractInterfaceBase_oshell;
};


class QDBusAbstractInterfaceBase_mshell : public QDBusAbstractInterfaceBase_shell
{
public:
    using QDBusAbstractInterfaceBase_shell::QDBusAbstractInterfaceBase_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
};


class QDBusAbstractInterfaceBase_oshell : public QDBusAbstractInterfaceBase_mshell
{
public:
    using QDBusAbstractInterfaceBase_mshell::QDBusAbstractInterfaceBase_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusAbstractInterfaceBase_access : public QDBusAbstractInterfaceBase
{
};

#endif // QDBUSABSTRACTINTERFACEBASE_SHELL_H
